#
# spec file for package openbabel
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# Allow disabling maestro (.mae) file support (enabled by default)
%bcond_without maestro

# Allow disabling GUI build (enabled by default)
%bcond_without gui

# Upstream version is "openbabel-major-minor-patch" instead of "major.minor.patch"
%define upstream_version openbabel-3-1-1

# The major ABI version of the shared library
%define abiver 7

Name:           openbabel
Version:        3.1.1
Release:        2.8
Summary:        A chemistry toolbox
License:        GPL-2.0-only
Group:          Development/Libraries/C and C++
URL:            https://openbabel.org
Source0:        https://github.com/openbabel/openbabel/archive/%{upstream_version}/%{name}-%{version}.tar.gz
# PATCH-FIX-UPSTREAM openbabel-3.1.1-test-python3-escape-chars.patch -- Fix test failure with python3 (gh#openbabel/openbabel#2217)
Patch0:         openbabel-3.1.1-test-python3-escape-chars.patch
# PATCH-FIX-UPSTREAM openbabel-3.1.1-test-python3-imports.patch -- Fix ImportError in python3 tests (gh#openbabel/openbabel!2378)
Patch1:         openbabel-3.1.1-test-python3-imports.patch
# PATCH-FIX-UPSTREAM openbabel-3.1.1-version-number.patch -- Fix version number
Patch2:         openbabel-3.1.1-version-number.patch
# PATCH-FIX-UPSTREAM openbabel-3.1.1-gcc-12.patch -- Fix build with GCC 12 (gh#openbabel/openbabel!2493)
Patch3:         openbabel-3.1.1-gcc-12.patch
# PATCH-FIX-UPSTREAM openbabel-3.1.1-wx-stl-compat.patch -- Fix build with wxWidgets using STL (gh#openbabel/openbabel!2527)
Patch4:         openbabel-3.1.1-wx-stl-compat.patch
BuildRequires:  cmake >= 3.1
BuildRequires:  gcc-c++
BuildRequires:  inchi-devel >= 1.04
BuildRequires:  ninja
BuildRequires:  pkgconfig
BuildRequires:  swig >= 2.0
BuildRequires:  pkgconfig(RapidJSON) >= 1.1.0
BuildRequires:  pkgconfig(cairo)
BuildRequires:  pkgconfig(eigen3) >= 2.91.0
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(python3)
BuildRequires:  pkgconfig(zlib)
%if %{with gui}
BuildRequires:  wxWidgets-devel >= 2.8
%endif
%if %{with maestro}
BuildRequires:  maeparser-devel >= 1.2.3
%endif

%description
Open Babel is a chemical toolbox understanding many formats of
chemical data. It allows to search, convert, analyze, or store data
from molecular modeling, chemistry, solid-state materials,
biochemistry, or related areas.

This package contains the command-line utility, which is intended to
be used as a replacement for the original babel program, to translate
between various chemical file formats as well as a wide variety of
utilities to foster development of other open source scientific
software.

%if %{with gui}
%package gui
Summary:        Graphical User Interface for Open Babel, a chemical toolbox
Group:          Productivity/Scientific/Chemistry

%description gui
Open Babel is a chemical toolbox understanding many formats of
chemical data. It allows to search, convert, analyze, or store data
from molecular modeling, chemistry, solid-state materials,
biochemistry, or related areas.

This package contains a graphical interface for Open Babel.
%endif

%package -n libopenbabel%{abiver}
Summary:        Component library of Open Babel, a chemistry toolbox
Group:          System/Libraries

%description -n libopenbabel%{abiver}
Open Babel is a chemical toolbox understanding many formats of
chemical data. It allows to search, convert, analyze, or store data
from molecular modeling, chemistry, solid-state materials,
biochemistry, or related areas.

This package contains the shared library of Open Babel.

%package -n python3-openbabel
Summary:        Python bindings for Open Babel, a chemistry toolbox
Group:          Productivity/Scientific/Chemistry

%description -n python3-openbabel
Open Babel is a chemical toolbox understanding many formats of
chemical data. It allows to search, convert, analyze, or store data
from molecular modeling, chemistry, solid-state materials,
biochemistry, or related areas.

This package contains the Python bindings of Open Babel.

%package devel
Summary:        Development files for Open Babel
Group:          Development/Libraries/C and C++
Requires:       libopenbabel%{abiver} = %{version}
Requires:       pkgconfig(zlib)
Provides:       libopenbabel-devel = %{version}
Obsoletes:      libopenbabel-devel < %{version}

%description devel
Open Babel is a chemical toolbox understanding many formats of
chemical data. It allows to search, convert, analyze, or store data
from molecular modeling, chemistry, solid-state materials,
biochemistry, or related areas.

%prep
%autosetup -p1 -n "%{name}-%{upstream_version}"

%build
%define __builder ninja
%cmake \
  -DRUN_SWIG=ON \
  -DPYTHON_BINDINGS=ON \
  -DPYTHON_EXECUTABLE=%{_bindir}/python3 \
  -DOPENBABEL_USE_SYSTEM_INCHI=ON \
  %{?with_maestro:-DWITH_MAEPARSER=ON} \
  -ULIB_INSTALL_DIR \
  -Wno-dev
%cmake_build

%install
%cmake_install

%post -n libopenbabel%{abiver} -p /sbin/ldconfig
%postun -n libopenbabel%{abiver} -p /sbin/ldconfig

%check
%ifarch aarch64 %{power64} riscv64
  # See gh#openbabel/openbabel/266, gh#openbabel/openbabel#2246
  %define test_filter --exclude-regex "(test_regressions_1|test_regressions_221|test_regressions_228|inchiSteffen_PubChem.smi_Test|pytest_sym|pybindtest_obconv_writers|pybindtest_bindings)"
%else
  # Some test failures on Tumbleweed apparently linked to slight changes in floating point value outputs.
  # They look harmless - maybe float comparison margin is just not big enough - and may be linked to newer rapidjson.
  %if 0%{?suse_version} > 1500
    %ifarch %{ix86}
      %define test_filter --exclude-regex "(pybindtest_obconv_writers|test_cifspacegroup_11|pybindtest_bindings)"
    %else
      %define test_filter --exclude-regex "pybindtest_obconv_writers"
    %endif
  %endif
%endif
%ifarch riscv64
%global test_filter --timeout 3000 %{?test_filter}
%endif

%ctest %{?test_filter}

%files
%{_bindir}/roundtrip
%{_bindir}/ob*
%{_mandir}/man1/*
%exclude %{_bindir}/obgui
%exclude %{_mandir}/man1/obgui.1*

%if %{with gui}
%files gui
%{_bindir}/obgui
%{_mandir}/man1/obgui.1%{?ext_man}
%dir %{_datadir}/openbabel
%dir %{_datadir}/openbabel/%{version}
%{_datadir}/openbabel/%{version}/splash.png
%endif

%files -n libopenbabel%{abiver}
%{_libdir}/libopenbabel.so.%{abiver}
%{_libdir}/libopenbabel.so.%{abiver}.0.0
# Library plugins
%dir %{_libdir}/openbabel
%{_libdir}/openbabel/%{version}
# Data files needed by either the library or its plugins
%dir %{_datadir}/openbabel
%{_datadir}/openbabel/%{version}
%exclude %{_datadir}/openbabel/%{version}/splash.png

%files devel
%dir %{_libdir}/cmake/openbabel3
%{_includedir}/openbabel3
%{_libdir}/cmake/openbabel3/OpenBabel3Config.cmake
%{_libdir}/cmake/openbabel3/OpenBabel3ConfigVersion.cmake
%{_libdir}/cmake/openbabel3/OpenBabel3_EXPORTS*.cmake
%{_libdir}/libopenbabel.so
%{_libdir}/pkgconfig/openbabel-3.pc

%files -n python3-openbabel
%{python3_sitearch}*

%changelog
* Tue Jul 18 2023 Andreas Schwab <schwab@suse.de>
- Skip problematic tests and increase timeout on riscv64
* Fri Aug 26 2022 Antoine Belvire <antoine.belvire@opensuse.org>
- Don't define %%upstream version from %%version: %%upstream_version
  is used in Source tag and osc download service does not evaluate
  %%() nor %%{lua:} in Source tags for security reasons.
- Drop entirely baselibs.conf: 32bit libraries seem unnecessary.
* Tue Aug 23 2022 Antoine Belvire <antoine.belvire@opensuse.org>
- Remove libinchi0 from baselibs.conf: Bundled inchi is not built
  anymore.
* Sun Aug 14 2022 Antoine Belvire <antoine.belvire@opensuse.org>
- Update to version 3.1.1:
  * Fixes for packaging.
  * No features or significant bug fixes were involved.
- Changes from version 3.1.0:
  * This version represents additional API and is
    backwards-compatible with the 3.0 release.
  * For a full list of changes, see:
    https://open-babel.readthedocs.io/en/latest/ReleaseNotes/ob310.html
- Changes from version 3.0.0:
  * This release represents a major update and is strongly
    recommended for all users.
  * It also removes deprecated components and breaks the API in a
    few places. For information on migrating from the previous
    version, please see:
    https://open-babel.readthedocs.io/en/latest/UseTheLibrary/migration.html#migrating-to-3-0
  * A sample of major new features:
    + Code for handling implicit hydrogens and kekulization has
    been entirely replaced. As well as being accurate, the new
    approach is much faster.
    + Speed of reading and writing SMILES has been improved by
    more  than 50-fold.
    + Removal of the old 'babel' binary in favor of the newer
    'obabel' command-line tool.
    + New improved fragment-based 3D coordinate generation code.
    + New API for handling reactions stored as molecules (e.g.
    Reaction InChI, etc.).
    + New API for copying part of an OBMol as a substructure.
    + Support for Maestro file format.
  * For a full list of changes, see:
    https://open-babel.readthedocs.io/en/latest/ReleaseNotes/ob300.html
- Remove upstreamed patches:
  * fix_narrowing.patch
  * fix_yasara.patch
- Add patches:
  * openbabel-3.1.1-test-python3-escape-chars.patch: Fix python
    test failure (gh#openbabel/openbabel#2217).
  * openbabel-3.1.1-test-python3-imports.patch: Fix ImportError in
    python tests (gh#openbabel/openbabel!2378).
  * openbabel-3.1.1-version-number.patch: Fix version number.
  * openbabel-3.1.1-gcc-12.patch: Fix build with GCC 12
    (gh#openbabel/openbabel!2493).
  * openbabel-3.1.1-wx-stl-compat.patch: Fix GUI build against
    wxWidgets compiled with STL (gh#openbabel/openbabel!2527).
- Build against system's inchi library instead of the bundled one.
- Add maeparser-devel as build dependency: Needed for Maestro
  support.
- Update subpackages:
  * Compile and package GUI.
  * Move plugins from CLI package (i.e. main package) to library
    package: They should be available to other library clients
    without requiring the CLI tools.
  * Move data files from CLI package to library package: Some are
    required by the library, some are required by its plugins,
    let's move everything to library package for now.
- Drop __DATE__ and __TIME__ tweaks for reproducibility: These GCC
  macros now use SOURCE_DATE_EPOCH.
- Enable tests.
* Mon Mar 30 2020 Martin Pluskal <mpluskal@suse.com>
- Modernise spec file
- Drop old conditionals
- Use ninja as builder
- Build only python3 bindings
* Wed May 16 2018 guillaume.gardet@opensuse.org
- Backport https://github.com/openbabel/openbabel/commit/e26491
  * fix_narrowing.patch
- Backport https://github.com/openbabel/openbabel/commit/8d707b
  * fix_yasara.patch
* Sun May 13 2018 wbauer@tmo.at
- Don't delete command line tools, include them in the main package
  as with openbabel < 2.4
- Pass -ULIB_INSTALL_DIR to unset this var, the %%cmake macro sets
  it to %%{_libdir} resulting in a duplicate /usr in the module
  search path which causes the plugins not to be found (boo#997190)
* Wed Feb 21 2018 wbauer@tmo.at
- Provide/Obsolete libopenbabel-devel for compatibility
* Sun Feb 18 2018 jengelh@inai.de
- Fix RPM groups. Update descriptions.
* Sat Feb  3 2018 wbauer@tmo.at
- Force python2 by passing -DPYTHON_EXECUTABLE=%%{_bindir}/python2
  to cmake to fix build on Tumbleweed
* Mon Feb  6 2017 mailaender@opensuse.org
- build with wxWidgets support
- add baselibs.conf
- enable python support (for real now)
- add libinchi0 and openbabel sub packages
- correct the .so version suffix for libopenbabel
- Drop openbabel-2.3.1-no-build-date.patch
* Sun Nov 20 2016 aloisio@gmx.com
- Update to version 2.4.1, see
  https://sourceforge.net/projects/openbabel/files/openbabel/2.4.0
  for changelog
- Dropped cripple_source.sh
- Replaced openbabel-2.2.3-no-build-date.patch with
  sed regex
- Dropped build-checks.diff due to significant source
  changes
- Dropped python-installdir.patch (included upstream)
- Dropped openbabel-gcc5.patch (included upstream)
* Sun Jun 19 2016 schwab@suse.de
- openbabel-gcc6.patch: remove obsolete hunk
* Fri Jun 17 2016 martin.liska@suse.com
- Fix errors seen by 02-check-gcc-output script.
* Thu Jun 16 2016 tchvatal@suse.com
- Version update to 2.3.2 and cripple the tarball
  * various small bugfixes, the git is far away from this but
    upstream seems not to do releases
  * Add patch to properly install bindings to right location:
    + python-installdir.patch
* Thu Jun 16 2016 mliska@suse.cz
- Add patch to build with gcc6 openbabel-gcc6.patch
* Fri Jun 19 2015 dimstar@opensuse.org
- Add openbabel-gcc5.patch: Fix build with gcc5.
* Mon Aug  5 2013 hrvoje.senjan@gmail.com
- enable CMAKE_SKIP_INSTALL_RPATH option so RPATH is ommited from
  install tree
* Tue Nov 20 2012 nico.kruber@gmail.com
- Fix the SLES build (%%make_install is not expanded on SLES)
* Thu Apr  5 2012 coolo@suse.com
- add -32bit libs for avogadro
* Fri Mar 23 2012 dhall@wustl.edu
- Add python bindings
* Tue Nov 29 2011 ro@suse.de
- determine arch suffix from _lib macro
* Tue Oct 18 2011 dhall@wustl.edu
- updated to OpenBabel 2.3.1
  * Better support for unknown stereochemistry, including a "wobbly" bond in 2D depiction.
  * Many fixes for rare bugs with stereochemical conversions, including unusual valences.
  * Significantly improved 2D depiction code, improving performance and cis/trans stereochemical accuracy
  * Added support for direct 2D depiction to PNG files using the Cairo library, if available.
  * PNG files from Open Babel contain molecular information and can be read to give the MDL Molfile.
  * SVG files with 2D depiction can now include a grid of molecules with embedded JavaScript to zoom and scroll.
  * Molecular formulas now include the total charge (e.g., HCO2-)
  * Added the EEM partial charge model from Bultinck, et. al.
  * Fixed problems with FastSearch databases larger than 4GB, now checking for large files.
  * Improved performance with force field minimization, particularly the UFF and GAFF methods.
  * Several MMFF94 atom typing bugs fixed.
  * Updated GAFF parameters from the AmberTools distribution.
  * Improvements in 3D coordinate generation, particularly more accurate sp3 bond angles
  * Fixed tests for auto-typing molecules with force fields when running through different isomers.
  * Improvements in scripting bindings, particularly Python, Ruby, and Java
  * Pybel now uses the built-in 2D depiction, and no longer needs OASA.
  * Added initial support for MM3 atom typing with the Tinker package
  * Significant bug fixes for the PDBQT format.
  * Reading FASTA files can now generate 3D coordinates for single-stranded DNA in addition to the default double-strand.
  * Support for reading/writing unit cell information from MOPAC files.
  * Support for re-numbering SMILES by specifying the first and last atoms with -xf and -xl flags.
  * Better support for InChI -> InChI key generation by direct conversion, rather than re-perception of the InChI.
  * Fix for rare stack overflow crash in SMARTS perception.
  * Improved UNIX man pages.
  * Many bug fixes and small enhancements
  * New File Formats
  * Import and Export:
  * Gromacs GRO
  * Import:
  * ABINIT
  * XCrySDen XSF
  * Export:
  * InChI Key
* Sat Jun 18 2011 dhall@wustl.edu
- use rpm %%ifarch
* Fri Jun 17 2011 dhall@wustl.edu
- Updated to OpenBabel 2.3.0
  * Completely rewritten stereochemistry perception, including support
    for tetrahedral, square planar, and higher-order stereochemistry.
  * Dramatically improved canonicalization algorithm (Note that in general, canonical SMILES have changed since the 2.2.x release.)
  * 2D depiction, including SVG vector graphics generation using code from MCDL.
  * New Spectrophore generation, contributed by Silicos NV.
  * New ChargeMethod API including support for partial charge assignment
    from Gasteiger, MMFF94, QEq, QTPIE methods and plugin interface for
    adding more.
  * Improved 3D coordinate generation.
  * New conformer generation framework, including support for diverse
    conformer generation and genetic algorithm lowest-energy searching.
  * Improved user documentation.
  * Improved aromaticity / Kekule bond assignment.
  * Improved unit test suite using the CMake-based CTest program.
  * Improved support for crystallographic unit cells (e.g., in CIF format).
  * Improved UFF force field method, including hypervalent 5, 6, 7 and higher coordination numbers.
  * Support for the GAFF (Generalized Amber Force Field) method.
  * Support for reading geometry optimizations as multiple conformers
    from Gaussian, GAMESS-US, and other quantum chemistry packages.
  * Support for reading molecular orbital energies from quantum chemistry formats.
  * Several memory leaks fixed.
  * Fixed many compiler warnings.
  * Fixed support for MinGW and Cygwin environments.
  * Fixed bugs with Gaussian 09 output files.
  * Latest released version of the InChI library (1.0.3) generating standard InChI.
  * Many more bug fixes and small feature improvements.
* Mon Sep 13 2010 cristian.rodriguez@opensuse.org
- Do not include build dates in binaries.
* Sat Sep 11 2010 alinm.elena@gmail.com
- added pkg-config to remove the error during the build
* Sat Sep 11 2010 alinm.elena@gmail.com
- Updated to OpenBabel 2.2.3
  * Improved Java interface
  * Many fixes to the fingerprint code
  * Added support of the pH parameter to the GUI
  * Several bug fixes and small enhancements-
* Sat Jul 25 2009 beineri@opensuse.org
- update to OpenBabel 2.2.2:
  * Fixed many stereochemistry errors when reading/writing SMILES.
  * Significantly improved aromaticity and Kekule bond assignment.
  * Improved 2D -> 3D coordinate generation
  * Improved coordinate generation using --gen3d command-line operation
  * Improved performance for coordinate generation.
  * New --fillUC command-line operation for babel.
  * Fixes to pH-dependent hydrogen addition.
  * Added support for reading vibrational data from Molden, Molpro,
    and NWChem output files.
  * Updated atomic radii from recent theoretical calculations.
  * Fixed bug when reading gzip-compressed Mol2 or XML files.
  * Close files after an error. Fixes a bug with Pybel where files
    would remain open.
  * New File Formats Import & Export:
  - Molpro input and output.
  - VASP coordinate files (CONTCAR and POSCAR).
- update to OpenBabel 2.2.1:
  * Added support for MACCS fingerprints.
  * Many fixes and enhancements to the force field code.
  * Improved 3D coordinate generation, particularly with ring fragments.
  * Fixed a variety of PDB import errors with atom types.
  * Added support for reading charges and radii from PQR file formats.
  * Added support for reading and writing unit cells in PDB formats.
  * New "output" file format for taking generic ".out", ".log", and
    ".dat" files and reading with appropriate file type based on contents.
  * Added improved error handling/reporting when unable to load file formats.
  * Improved CIF file format support.
  * Generic "output" format for reading from quantum chemistry files.
* Tue Jul 22 2008 dmueller@suse.de
- cripple tarball to remove binary dll's we don't need (bnc#411171)
* Sat Jul 19 2008 dmueller@suse.de
- various fixes, fix library package name
* Wed Jul  9 2008 dmueller@suse.de
- review last change
* Wed Jul  9 2008 cniehaus@kde.org
- update to OpenBabel 2.2.0:
  * http://openbabel.org/wiki/Open_Babel_2.2.0
* Sun Oct 21 2007 dmueller@suse.de
- gcc 4.3 fixes
* Mon Oct  8 2007 dmueller@suse.de
- Initial package (2.1.1)
